Module formatter

Module formatter 

CQLite table formatter for cqlsh-compatible output

This module implements table formatting that exactly matches cqlsh output format, based on the comprehensive research in CQLSH_FORMAT_SPECIFICATION.md

Structs

CqlshTableFormatter
Table formatter for cqlsh-compatible output

Constants

COLUMN_SEPARATOR
Constants for cqlsh-compatible formatting
HEADER_BORDER_CHAR
HEADER_SEPARATOR_JUNCTION
ROW_PREFIX

Functions

format_for_cqlsh_comparison
Format data for cqlsh comparison
format_sstable_entries_as_table
Utility function to format SSTable entries for display