execute_schema_list

Function execute_schema_list 

pub async fn execute_schema_list(schema_paths: &[PathBuf]) -> Result<()>
Execute the :schema list command

Displays loaded schema file paths with a simple numbered list. Shows helpful hint when no schemas are loaded.

Arguments

  • schema_paths - Reference to the list of currently loaded schema file paths

Returns

Returns Ok(()) on success, or an error if display operations fail