CQLite table formatter for cqlsh-compatible output
This module implements table formatting that exactly matches cqlsh output format, based on the comprehensive research in CQLSH_FORMAT_SPECIFICATION.md
Structs
- Cqlsh
Table Formatter - Table formatter for cqlsh-compatible output
Constants
- COLUMN_
SEPARATOR - Constants for cqlsh-compatible formatting
- HEADER_
BORDER_ CHAR - HEADER_
SEPARATOR_ JUNCTION - ROW_
PREFIX
Functions
- format_
for_ cqlsh_ comparison - Format data for cqlsh comparison
- format_
sstable_ entries_ as_ table - Utility function to format SSTable entries for display